<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Lec’hioù ha sindikadur e SPIP (prevez ha publik)',
	'sites_slogan' => 'Merañ al lec’hioù ha sindikadur e SPIP',
];
